@@ -470,28 +470,33 @@ def search(
 
     for page in tqdm(page_list, total=len(page_list), desc="Scrapping"):
 
-        params = {
-            "action": action,
-            "state_type": type,
-            "localization": localization,
-            "page": page,
-        }
+        try:
 
-        search_result = search_page(timeout=timeout, **params)
+            params = {
+                "action": action,
+                "state_type": type,
+                "localization": localization,
+                "page": page,
+            }
 
-        time.sleep(simulated_time(sleep_time_mean, sleep_time_std, sleep_time_bias))
+            search_result = search_page(timeout=timeout, **params)
 
-        info = pd.DataFrame(format_search(search_result, **params))
+            time.sleep(simulated_time(sleep_time_mean, sleep_time_std, sleep_time_bias))
 
-        df_dados = empty_df.append(info).set_index("search_id")
+            info = pd.DataFrame(format_search(search_result, **params))
 
-        for col in df_dados:
-            try:
-                df_dados[col] = df_dados[col].apply(str)
-            except:
-                pass
+            df_dados = empty_df.append(info).set_index("search_id")
 
-        results = results.append(df_dados.reset_index())
+            for col in df_dados:
+                try:
+                    df_dados[col] = df_dados[col].apply(str)
+                except:
+                    pass
+
+            results = results.append(df_dados.reset_index())
+
+        except Exception as err:
+            print(err)
 
     return results
 
